==> spatialpandas-0.4.10rc1.tar.gz: spatialpandas-0.4.10rc1/README.md <==
<img src="https://github.com/holoviz/spatialpandas/raw/main/doc/_static/logo_horizontal.png" data-canonical-src="https://github.com/holoviz/spatialpandas/raw/main/doc/_static/logo_horizontal.png" width="380"/><br>

-----------------

# Pandas and Dask extensions for vectorized spatial and geometric operations.

|    |    |
| --- | --- |
| Build Status | [![pytest](https://github.com/holoviz/spatialpandas/workflows/tests/badge.svg)](https://github.com/holoviz/spatialpandas/actions?query=workflow%3Atests) |
| Latest dev release | [![Github tag](https://img.shields.io/github/tag/holoviz/spatialpandas.svg?label=tag&colorB=11ccbb)](https://github.com/holoviz/spatialpandas/tags)|
| Latest release | [![Github release](https://img.shields.io/github/release/holoviz/spatialpandas.svg?label=tag&colorB=11ccbb)](https://github.com/holoviz/spatialpandas/releases) [![PyPI version](https://img.shields.io/pypi/v/spatialpandas.svg?colorB=cc77dd)](https://pypi.python.org/pypi/spatialpandas) [![spatialpandas version](https://img.shields.io/conda/v/pyviz/spatialpandas.svg?colorB=4488ff&style=flat)](https://anaconda.org/pyviz/spatialpandas) [![conda-forge version](https://img.shields.io/conda/v/conda-forge/spatialpandas.svg?label=conda%7Cconda-forge&colorB=4488ff)](https://anaconda.org/conda-forge/spatialpandas) [![defaults version](https://img.shields.io/conda/v/anaconda/spatialpandas.svg?label=conda%7Cdefaults&style=flat&colorB=4488ff)](https://anaconda.org/anaconda/spatialpandas) |
| Python | [![Python support](https://img.shields.io/pypi/pyversions/spatialpandas.svg)](https://pypi.org/project/spatialpandas/)
| Support | [![Discourse](https://img.shields.io/discourse/status?server=https%3A%2F%2Fdiscourse.holoviz.org)](https://discourse.holoviz.org/) |

-----------------

Spatialpandas provides Pandas and Dask extensions for vectorized spatial and geometric operations, such as fast, spatially indexed rendering of large collections of polygons, lines, or points. For more information, see the [overview notebook](https://nbviewer.jupyter.org/github/holoviz/spatialpandas/blob/main/examples/Overview.ipynb) and the [design document](https://github.com/holoviz/spatialpandas/issues/1#issue-513306469).

==> spatialpandas-0.5.0a2.tar.gz: spatialpandas-0.5.0a2/README.md <==
<img src="https://github.com/holoviz/spatialpandas/raw/main/doc/_static/logo_horizontal.png" data-canonical-src="https://github.com/holoviz/spatialpandas/raw/main/doc/_static/logo_horizontal.png" width="380"/><br>

-----------------

# Pandas and Dask extensions for vectorized spatial and geometric operations.

|    |    |
| --- | --- |
| Build Status | [![Build Status](https://github.com/holoviz/spatialpandas/actions/workflows/test.yaml/badge.svg?branch=main)](https://github.com/holoviz/spatialpandas/actions/workflows/test.yaml?query=branch%3Amain) |
| Coverage | [![codecov](https://codecov.io/gh/holoviz/spatialpandas/branch/main/graph/badge.svg)](https://codecov.io/gh/holoviz/spatialpandas) |
| Latest dev release | [![Github tag](https://img.shields.io/github/tag/holoviz/spatialpandas.svg?label=tag&colorB=11ccbb)](https://github.com/holoviz/spatialpandas/tags) |
| Latest release | [![Github release](https://img.shields.io/github/release/holoviz/spatialpandas.svg?label=tag&colorB=11ccbb)](https://github.com/holoviz/spatialpandas/releases) [![PyPI version](https://img.shields.io/pypi/v/spatialpandas.svg?colorB=cc77dd)](https://pypi.python.org/pypi/spatialpandas) [![spatialpandas version](https://img.shields.io/conda/v/pyviz/spatialpandas.svg?colorB=4488ff&style=flat)](https://anaconda.org/pyviz/spatialpandas) [![conda-forge version](https://img.shields.io/conda/v/conda-forge/spatialpandas.svg?label=conda%7Cconda-forge&colorB=4488ff)](https://anaconda.org/conda-forge/spatialpandas) [![defaults version](https://img.shields.io/conda/v/anaconda/spatialpandas.svg?label=conda%7Cdefaults&style=flat&colorB=4488ff)](https://anaconda.org/anaconda/spatialpandas) |
| Python | [![Python support](https://img.shields.io/pypi/pyversions/spatialpandas.svg)](https://pypi.org/project/spatialpandas/) |
| Support | [![Discourse](https://img.shields.io/discourse/status?server=https%3A%2F%2Fdiscourse.holoviz.org)](https://discourse.holoviz.org/) |

-----------------

Spatialpandas provides Pandas and Dask extensions for vectorized spatial and geometric operations, such as fast, spatially indexed rendering of large collections of polygons, lines, or points. For more information, see the [overview notebook](https://nbviewer.jupyter.org/github/holoviz/spatialpandas/blob/main/examples/Overview.ipynb) and the [design document](https://github.com/holoviz/spatialpandas/issues/1#issue-513306469).
